/**
 * @typedef {JSON & {properties: object}} JsonSchema
 * @element eox-jsonform
 */
export class EOxJSONForm extends LitElement {
    static properties: {
        schema: {
            attribute: boolean;
            type: ObjectConstructor;
        };
        value: {
            attribute: boolean;
            type: ObjectConstructor;
        };
        options: {
            attribute: boolean;
            type: ObjectConstructor;
        };
        customEditorInterfaces: {
            attribute: boolean;
            type: ArrayConstructor;
        };
        noShadow: {
            attribute: string;
            type: BooleanConstructor;
        };
        unstyled: {
            type: BooleanConstructor;
        };
    };
    /**
     * Setter for the JSON schema used to render the form
     *
     * @param {JsonSchema} newSchema
     */
    set schema(newSchema: JsonSchema);
    /**
     * Getter for the JSON schema used to render the form
     *
     * @return {JsonSchema | String}
     */
    get schema(): JsonSchema | string;
    /**
     *  Setter for the default values to fill the form
     *
     * @param {JsonSchema} newVal
     */
    set value(newVal: JsonSchema);
    /**
     * Getter for the default values to fill the form
     */
    get value(): JsonSchema;
    /**
     * Default values for the form editor
     *
     * @type {object}
     */
    options: object;
    /**
     * Renders the element without a shadow root
     *
     * @type {Boolean}
     */
    noShadow: boolean;
    /**
     * Render the element without additional styles
     *
     * @type {Boolean}
     */
    unstyled: boolean;
    /**
     * List of custom editor interface
     * Read more about the implementation of custom editor interfaces here:
     * https://github.com/json-editor/json-editor/blob/master/docs/custom-editor.html
     *
     * @type {Array}
     */
    customEditorInterfaces: any[];
    /**
     * Getter for the JSONEditor instance
     */
    get editor(): {
        [key: string]: any;
    };
    _schema: string | import("./helpers/editor").JsonSchema | JsonSchema;
    _value: any;
    /**
     * Lifecycle method called when the element is updated
     *
     * @param {import("lit").PropertyValues} changedProperties
     */
    updated(changedProperties: import("lit").PropertyValues): Promise<void>;
    /**
     * Renders the component's HTML and CSS
     */
    render(): import("lit-html").TemplateResult<1>;
    #private;
}
export type JsonSchema = JSON & {
    properties: object;
};
import { LitElement } from "lit";
//# sourceMappingURL=main.d.ts.map